# Table of Contents

- [basic-settings](<./basic-settings.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Basic Settings](<./Basic-Settings.md>)
  - [In This Section](<./Basic-Settings/In-This-Section.md>)
  - [Was this page helpful?](<./Basic-Settings/Was-this-page-helpful.md>)
